#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-5Dh82ZmygBALyGkpTqM1u2
key:                  stack-2.9.3.1-5Dh82ZmygBALyGkpTqM1u2
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  78ba0ea59cb8625359349cc0311c7881
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-5Dh82ZmygBALyGkpTqM1u2
depends:
    Cabal-3.10.3.0 aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-CI3Z2kdMs2nHILfQB59SyQ array-0.5.6.0
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7 base-4.18.2.1
    base64-bytestring-1.2.1.0-6zbb0o9xH9hLkYSzTxgmy9
    bytestring-0.11.5.3 casa-client-0.0.3-BnRwY2Kbn4FKW1jYSBxC6Q
    casa-types-0.0.3-3SRQbTaMBkuC77LXKQao9W
    colour-2.3.6-AuqXCCc75dKHEPCsdi0KGg
    conduit-1.3.6.1-6FfN71X8NnX6xRLVW7u2GC
    conduit-extra-1.3.8-BK9Jc8PuJQZ8Xgs3mlG92k containers-0.6.7
    crypton-1.0.4-BW3r2zHLDkn5MXOxLzl4Qy
    crypton-conduit-0.2.3-8K6OEP0t3EQ54Jrt0xFgr9 deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-COAoMleqge7G93j2zK3Os3
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-EVDUrLdrKdGI2pLqSt6nSV filepath-1.4.300.1
    fsnotify-0.4.4.0-9tVbf3PdmIaLyWQzCtujGh
    generic-deriving-1.14.7-2lWWpnciduhFN9Mzh2GB5t
    hackage-security-0.6.3.2-K1Lmn1x9MatL8BXxbZ0tl6
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hi-file-parser-0.1.8.0-JRG6Q0yW9y1CZmEZmB2Pfi
    hpack-0.38.0-5A1WKGtxOh1GetCykp3Lzs hpc-0.6.2.0
    http-client-0.7.19-9meVfWioNG49hhaNpvORg0
    http-client-tls-0.3.6.4-64ZNym5SGVuSefUXbYwod
    http-conduit-2.3.9.1-FDAEjnTem1fH8L3DzGb7p6
    http-download-0.2.1.0-1NvMFg7aQo2ItF3NI4Anee
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-CeXYeFW75pW28gCGqOjYKl mtl-2.3.1
    mustache-2.4.3.1-DfH8ykRUMNvE5LKQn3EWhc
    neat-interpolation-0.5.1.4-4ZQ0mocWEkq6O1QVnG3T8u
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    pantry-0.8.2.2-6UNDBhsLL2q58yIuc5yDtZ
    path-0.9.6-9cZPJYsPpG86lbkCXwdano
    path-io-1.8.2-JyN2cWZEhn6JdFFEojygpC
    persistent-2.14.5.2-AnYNyOpqn2b5awZPxWmcki
    persistent-sqlite-2.13.2.0-8c2mxEG9cMD2ZaNpSQ3icD pretty-1.1.3.6
    primitive-0.9.1.0-2IRhja9DqVYHGJwyknHO82 process-1.6.19.0
    project-template-0.2.1.0-7wE9wif3NJvCqPVT8OQZuP
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    retry-0.9.3.1-DYXcfDrVsgV1h8rt2rgh5D
    rio-0.1.24.0-5PRtrW0Kqfk5xW2NXXZCvg
    rio-prettyprint-0.1.8.0-3ukUAMQUy5JAehQ7JKtiz4
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-3DKGo5U99N91TNuSptQK8x
    tar-0.5.1.1-8HzjX8EsYMlETyi0KNeAzk template-haskell-2.20.0.0
    temporary-1.3-imd8AcD6Pg3Lf1V6ZsYLS text-2.0.2
    text-metrics-0.3.3-GR8VcVhPgJ679oW6ciKE9p
    th-reify-many-0.1.10-KrVi6XMY6V2BZJwSzCMnCd time-1.12.2
    tls-2.0.6-ESG99sUHqcF1slFbYsFN92 transformers-0.6.1.0
    typed-process-0.2.13.0-Tq1cqbkmN5B9XQxMz1Iks
    unicode-transforms-0.4.0.1-JNNFONHexfK5saPZyDxG9m unix-2.8.4.0
    unix-compat-0.7.4.1-D5z0oaVDOHE7a26PpKdQ2K
    unliftio-0.2.25.1-FRGz7PceS9EF7fvbKOBYVe
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc
    yaml-0.11.11.2-81nK8rEhmQL8KSqKy3VGeK
    zip-archive-0.4.3.2-Kkk6wjExzKfF81A5C4XuYH
    zlib-0.7.0.0-4R5icK1yXLI4HdJUCaGWsH

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

